"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.controllerConsumes = exports.consumes = void 0;
const util_1 = require("util");
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator for an endpoint method that details the HTTP request Content-Type header value.
 *
 * Overrides the controller value set by the `controllerConsumes` decorator, if any.
 *
 * @param contentType Request content type.
 */
function consumes(contentType, apiBodyInfo) {
    return (classDefinition, methodName) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        let operationInfo = endpoint.getOrCreateApiOperationInfo();
        let requestInfo = operationInfo.getOrCreateRequest();
        if (DecoratorRegistry_1.DecoratorRegistry.getLogger().debugEnabled()) {
            DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@consumes('%s'%s) decorator executed for endpoint: %s", contentType, apiBodyInfo ? `, ${util_1.inspect(apiBodyInfo)}` : "", endpoint.name);
        }
        endpoint.consumes = contentType;
        requestInfo.contentType = contentType;
        if (apiBodyInfo) {
            requestInfo.mergeInfo(apiBodyInfo);
        }
    };
}
exports.consumes = consumes;
/**
 * Decorator for a controller class that details the HTTP request Content-Type header value for
 * all endpoints.
 *
 * @param contentType Request content type.
 */
function controllerConsumes(contentType, apiBodyInfo) {
    return (classDefinition) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition);
        let requestInfo = controller.getOrCreateRequestInfo();
        if (DecoratorRegistry_1.DecoratorRegistry.getLogger().debugEnabled()) {
            DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@controllerConsumes('%s'%s) decorator executed for controller: %s", contentType, apiBodyInfo ? `, ${util_1.inspect(apiBodyInfo)}` : "", controller.name);
        }
        controller.consumes = contentType;
        requestInfo.contentType = contentType;
        if (apiBodyInfo) {
            requestInfo.mergeInfo(apiBodyInfo);
        }
    };
}
exports.controllerConsumes = controllerConsumes;
//# sourceMappingURL=consumes.js.map