"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.controllerErrorInterceptor = exports.errorInterceptor = void 0;
const util_1 = require("util");
const DecoratorRegistry_1 = require("../../reflection/DecoratorRegistry");
/**
 * Decorator for an endpoint method that configures the type to use to intercept errors.
 *
 * Overrides the controller error interceptor set by the `controllerErrorInterceptor` decorator, if any.
 *
 * Error interceptors instances are built using the InversifyJS IOC container for the current app.
 */
function errorInterceptor(interceptor) {
    return (classDefinition, methodName) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition.constructor);
        let endpoint = DecoratorRegistry_1.DecoratorRegistry.getOrCreateEndpoint(controller, methodName);
        if (DecoratorRegistry_1.DecoratorRegistry.getLogger().debugEnabled()) {
            DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@errorInterceptor(%s) decorator executed for endpoint: %s", util_1.inspect(interceptor), endpoint.name);
        }
        endpoint.errorInterceptor = interceptor;
    };
}
exports.errorInterceptor = errorInterceptor;
/**
 * Decorator for a controller class that configures the type to use to intercept errors.
 *
 * Error interceptors instances are built using the current app InversifyJS IOC container.
 */
function controllerErrorInterceptor(interceptor) {
    return (classDefinition) => {
        let controller = DecoratorRegistry_1.DecoratorRegistry.getOrCreateController(classDefinition);
        if (DecoratorRegistry_1.DecoratorRegistry.getLogger().debugEnabled()) {
            DecoratorRegistry_1.DecoratorRegistry.getLogger().debug("@controllerErrorInterceptor(%s) decorator executed for controller: %s", util_1.inspect(interceptor), controller.name);
        }
        controller.errorInterceptor = interceptor;
    };
}
exports.controllerErrorInterceptor = controllerErrorInterceptor;
//# sourceMappingURL=errorInterceptor.js.map